@@ -397,7 +397,6 @@ ph_with.plot_instr <- function(x, value, location, res = 300, ...){
 #' @export
 #' @param use_loc_size if set to FALSE, external_img width and height will
 #' be used.
-#' @param alt_text Alt-text for screen-readers
 #' @describeIn ph_with add a \code{\link{external_img}} to a new shape
 #' on the current slide.
 #'
@@ -406,7 +405,7 @@ ph_with.plot_instr <- function(x, value, location, res = 300, ...){
 #' specified in call to \code{external_img} will be
 #' ignored, their values will be those of the location,
 #' unless use_loc_size is set to FALSE.
-ph_with.external_img <- function(x, value, location, use_loc_size = TRUE, alt_text, ...){
+ph_with.external_img <- function(x, value, location, use_loc_size = TRUE, ...){
   location <- fortify_location(location, doc = x)
 
   slide <- x$slide$get_slide(x$cursor)
@@ -436,7 +435,7 @@ ph_with.external_img <- function(x, value, location, use_loc_size = TRUE, alt_te
   xml_str <- pic_pml(left = location$left, top = location$top,
                        width = width, height = height,
                        label = location$ph_label, ph = location$ph,
-                       rot = location$rotation, bg = location$bg, src = new_src, alt_text = alt_text)
+                       rot = location$rotation, bg = location$bg, src = new_src, alt_text = attr(value, "alt"))
 
   slide$reference_img(src = new_src, dir_name = file.path(x$package_dir, "ppt/media"))
   xml_elt <- fortify_pml_images(x, xml_str)
