@@ -257,9 +257,9 @@ check_bookmark_id <- function(bkm){
     invalid_bkm <- is.character(bkm) &&
       length(bkm) == 1 &&
       nchar(bkm) > 0 &&
-      grepl("[^[:alnum:]_-]+", bkm)
+      grepl("[^:[:alnum:]_-]+", bkm)
     if(invalid_bkm){
-      stop("bkm [", bkm, "] should only contain alphanumeric characters, '-' and '_'.", call. = FALSE)
+      stop("bkm [", bkm, "] should only contain alphanumeric characters, ':', '-' and '_'.", call. = FALSE)
     }
   }
   bkm
