@@ -7,9 +7,9 @@ getncheck <- function(x, str){
 
 
 test_that("seqfield add ", {
-  x <- read_docx() %>%
-    body_add_par("Time is: ", style = "Normal") %>%
-    slip_in_seqfield(
+  x <- read_docx()
+  x <- body_add_par(x, "Time is: ", style = "Normal")
+  x <- slip_in_seqfield(x,
       str = "TIME \u005C@ \"HH:mm:ss\" \u005C* MERGEFORMAT")
 
   node <- x$doc_obj$get_at_cursor()
@@ -19,10 +19,10 @@ test_that("seqfield add ", {
   child_ <- getncheck(node, "w:r/w:instrText")
   expect_equal( xml_text(child_), "TIME \\@ \"HH:mm:ss\" \\* MERGEFORMAT" )
 
-  x <- body_add_par(x, " - This is a figure title", style = "centered") %>%
-    slip_in_seqfield(str = "SEQ Figure \u005C* roman",
-                     style = 'Default Paragraph Font', pos = "before") %>%
-    slip_in_text("Figure: ", style = "strong", pos = "before")
+  x <- body_add_par(x, " - This is a figure title", style = "centered")
+  x <- slip_in_seqfield(x, str = "SEQ Figure \u005C* roman",
+                     style = 'Default Paragraph Font', pos = "before")
+  x <- slip_in_text(x, "Figure: ", style = "strong", pos = "before")
   node <- x$doc_obj$get_at_cursor()
   expect_equal( xml_text(node), "Figure: SEQ Figure \\* roman - This is a figure title" )
 })
@@ -31,9 +31,9 @@ test_that("seqfield add ", {
 
 test_that("hyperlink add ", {
   href_ <- "https://github.com/davidgohel"
-  x <- read_docx() %>%
-    body_add_par("Here is a link: ", style = "Normal") %>%
-    slip_in_text(str = "the link", style = "strong", hyperlink = href_)
+  x <- read_docx()
+  x <- body_add_par(x, "Here is a link: ", style = "Normal")
+  x <- slip_in_text(x, str = "the link", style = "strong", hyperlink = href_)
 
   rel_df <- x$doc_obj$rel_df()
   expect_true( href_  %in% rel_df$target )
